This is the GUI for Genskew_univiecube, which will automatically be installed when installing Genskew_univiecube.

GenSkew is an application for computing and plotting nucleotide skew data.

GenSkew calculates the incremental and the cumulative skew of two selectable nucleotides for a given sequence according to this formula:
Skew = (nucleotide1 - nucleotide2) / (nucleotide1 + nucleotide2)

The results are provided as data table and as graphical plot. The global minimum and maximum are displayed in the cumulative graph. The minimum and maximum of a GC-skew can be used to predict the origin of replication (minimum) and the terminus location (maximum) in prokaryotic genomes.

Installing the program with the command you can copy above will install the Genskew library as well as the Genskew GUI. When pressing on the "Browse" button, you can select the sequence you want to use. With the two drop-down menus you can select the two nucleotides. Stepsize and windowsize can be left out, in which case they will be calculated by the program. The last drop down menu selects the file type that you can save. Pressing calculate will display the graph in the window, but not save it.

The use of the library is explained in detail on the pipy site of Genskew_univiecube.

There is also a commandline client availabe, which is called Genskew_cc on pipy.
